import pygame
import sys

from bombz import key
from bombz import menu

ALIGN_AROUND = 200
RENDER_WIDTH = 200
EXTRA_SPACE = 40

class KeyMenuItem(menu.LabelledMenuItem):
	def __init__(self, label, kmopts, opt_name, def_val = None):
		menu.LabelledMenuItem.__init__(self, label, ALIGN_AROUND)
		self.kmopts = kmopts
		self.opts = kmopts.opts
		self.opt_name = opt_name
		self.def_val = def_val
		self.activated = False

	def render_value(self, surf, x, y, fgcolor, bgcolor, highlighted):
		if self.activated:
			txt = '???'
		else:
			t = pygame.key.name(int(self.opts.lookup(self.opt_name,
				self.def_val)))
			txt = t[0].upper()
			if len(t) > 1:
				txt += t[1:]
		menu.render_text_centered_at(surf, txt, x + EXTRA_SPACE, y,
				RENDER_WIDTH, fgcolor, bgcolor, menu.FONT_SIZE, True)

	def activate(self):
		self.activated = True
		self.menu.redraw()
		while True:
			event = pygame.event.wait()
			if event.type == pygame.QUIT:
				sys.exit(0)
			elif event.type == pygame.KEYDOWN:
				if event.key == pygame.K_ESCAPE:
					break
				if event.key != pygame.K_RETURN:
					if not self.check_for_clashes(event.key):
						self.set_value(event.key)
						break
		self.activated = False
		self.menu.redraw()
	
	def check_for_clashes(self, k):
		if k in (pygame.K_UP, pygame.K_DOWN, pygame.K_LEFT, pygame.K_RIGHT, \
				pygame.K_RETURN, pygame.K_ESCAPE):
			return True
		for s in ("up", "down", "left", "right"):
			opt_name = "k_" + s
			if opt_name != self.opt_name:
				if s == 'up':
					dflt = pygame.K_l
				elif s == 'down':
					dflt = pygame.K_COMMA
				elif s == 'left':
					dflt = pygame.K_z
				elif s == 'right':
					dflt = pygame.K_x
				if k == int(self.opts.lookup(opt_name, dflt)):
					# FIXME: Some sort of feedback to indicate clash
					return True
		return False

	def set_value(self, k):
		self.opts.update(self.opt_name, k, True)
		kn = self.opt_name[2:] + '2'
		setattr(key, kn, k)


class KeyboardMenuOptions:
	def __init__(self, opts):
		self.opts = opts
		self.m_up = KeyMenuItem(_("Up"), self, 'k_up', pygame.K_l)
		self.m_down = KeyMenuItem(_("Down"), self, 'k_down', pygame.K_COMMA)
		self.m_left = KeyMenuItem(_("Left"), self, 'k_left', pygame.K_z)
		self.m_right = KeyMenuItem(_("Right"), self, 'k_right', pygame.K_x)

	def create_menu(self, logo = None):
		m = menu.Menu(_("Configure keyboard"), logo)
		self.menu = m
		m.append(self.m_up)
		m.append(self.m_down)
		m.append(self.m_left)
		m.append(self.m_right)
		m.append(menu.ExitMenuItem())
		return m
