import os
import sys

from bombz import userdir

_default_filename = None

def get_default_filename():
	global _default_filename 
	if not _default_filename:
		_default_filename = os.path.join(userdir.dirs.conf(), "config")
	return _default_filename

class Options:
	def __init__(self, filename = None):
		if not filename:
			filename = get_default_filename()
		self.filename = filename
		self.options = {}
		if os.path.exists(filename):
			fp = file(filename, 'r')
			lines = fp.readlines()
			fp.close()
			for l in lines:
				l = l.strip()
				if l[0] == '#' or not len(l):
					continue
				if l.find('=') == -1:
					print >> sys.stderr, \
							_("Invalid line '%s' in config file '%s'") \
								% (l, filename)
					continue
				[k, v] = l.split('=', 1)
				k = k.strip()
				v = v.strip()
				self.options[k] =  v
	
	def lookup(self, k, default = None):
		v = self.options.get(k)
		if not v:
			v = default
		return v

	def save(self, filename = None, comment = None):
		if not filename:
			filename = self.filename
		fp = file(filename, 'w')
		if not comment:
			comment = _("Bombz options")
		fp.write('# ' + comment + '\n')
		for item in self.options.items():
			if item[1] is not None:
				fp.write("%s = %s\n" % item)
		fp.close()
	
	def update(self, k, v, save = True):
		self.options[k] = v
		if save:
			self.save()

class Option:
	def __init__(self, name, options, def_val = None):
		""" options is the Options object this belongs to. """
		if def_val is not None and not options.lookup(name):
			options.options[name] = def_val
		self.name = name
		self.options = options
	def set(self, value, save = True):
		self.options.update(self.name, value, save)
	def get(self):
		return self.options.options.get(self.name)

