import pygame

from bombz import joymenu, keymenu, menu, options, particles

class OptionsMenu(menu.Menu):
	def __init__(self, opts, logo, o_fullscreen, fullscreen_toggled):
		menu.Menu.__init__(self, _("Options"), logo)
		self.opts = opts
		self.create_keyboard_menu(opts, logo)
		self.create_joystick_menu(opts)
		self.append(menu.BoolMenuItem(fullscreen_toggled,
			_("Display mode"), int(o_fullscreen.get()),
			(_("Windowed"), _("Full screen"))))
		self.append(menu.MenuItem(self.open_keyboard_menu,
			_("Configure keyboard")))
		i = menu.MenuItem(self.open_joystick_menu,
				_("Configure game controller"))
		if pygame.joystick.get_count() < 1:
			i.sensitive = False
		self.append(i)
		self.append(menu.SliderMenuItem(_("Particles"), 0, 512, 64,
				int(opts.lookup("particles", particles.max_particles)),
				self.particles_updated))
		self.append(menu.ExitMenuItem(_("Back")))
	
	def particles_updated(self, value):
		value = int(value)
		self.opts.update("particles", value)
		particles.set_max_particles(value)

	def create_joystick_menu(self, opts):
		self.joystick_opts = joymenu.JoystickMenuOptions(opts)
		# Menu too long, no room for logo
		self.joystick_menu = self.joystick_opts.create_menu()

	def create_keyboard_menu(self, opts, logo):
		self.keyboard_opts = keymenu.KeyboardMenuOptions(opts)
		self.keyboard_menu = self.keyboard_opts.create_menu(logo)

	def open_joystick_menu(self):
		self.showing = False
		self.joystick_menu.show(self.surface)
		self.joystick_menu.event_loop()
		self.show(self.surface)

	def open_keyboard_menu(self):
		self.showing = False
		self.keyboard_menu.show(self.surface)
		self.keyboard_menu.event_loop()
		self.show(self.surface)

