import math
import random

MIN_BRIGHTNESS = 100
MAX_ITERS = 50
MIN_ITERS = 20
MIN_VELOCITY = 1
MAX_VELOCITY = 20
MAX_X = 640
MAX_Y = 480

max_particles = 256
flurry_size = 25

particles = []

class Particle:
	def __init__(self, x, y):
		self.randomise_colour()
		velocity = random.uniform(MIN_VELOCITY, MAX_VELOCITY)
		angle = random.random() * 2 * math.pi
		self.dx = velocity * math.cos(angle)
		self.dy = velocity * math.sin(angle)
		self.x = float(x) + self.dx
		self.y = float(y) + self.dy
		self.iters = 0
		self.max_iters = random.randint(MIN_ITERS, MAX_ITERS)
		self.dead = False
	
	def randomise_colour(self):
		self.colour = [random.randint(MIN_BRIGHTNESS, 255),
				random.randint(MIN_BRIGHTNESS, 255), 
				random.randint(MIN_BRIGHTNESS, 255)]

	def process(self):
		self.iters += 1
		self.randomise_colour()
		if self.iters > self.max_iters:
			self.dead = True
		self.x += self.dx
		self.y += self.dy
		if self.x < 0 or self.x >= MAX_X or self.y < 0 or self.y >= MAX_Y:
			self.dead = True
	
	def render(self, surface):
		if not self.dead:
			surface.set_at((int(self.x), int(self.y)), self.colour)

def create_flurry(x, y):
	for i in range(flurry_size):
		if len(particles) > max_particles:
			return
		particles.append(Particle(x, y))

def process_all(surface):
	i = len(particles)
	surface.lock()
	while i > 0:
		i -= 1
		p = particles[i]
		p.process()
		p.render(surface)
		if p.dead:
			del particles[i]
	surface.unlock()

def delete_all():
	i = len(particles)
	while i > 0:
		i -= 1
		del particles[i]

def set_max_particles(n):
	global max_particles, flurry_size
	max_particles = int(n)
	flurry_size = int(max_particles / 10)

def init(opts):
	set_max_particles(opts.lookup("particles", 256))
	
